==> sim_dhaman-0.0.2.tar.gz: example/lib/main.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:sim_dhaman/sim_dhaman.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  TextEditingController Number_Call_Controler = TextEditingController();
  String _selectedSimCard = "";
  List<String> _simcards = [];

  @override
  void initState() {
    super.initState();
    // initPlatformState();
  }

  getAllSimCard() async {
    var simcards = await SimDhaman.allsimcard();

    if (simcards.length > 0) {
      setState(() {
        _simcards = simcards;
        _selectedSimCard = simcards.first;
      });
    }

    print(simcards);
  }

  Call_On_SomCard() {
    var numberToDial = Number_Call_Controler.text;
    SimDhaman.call_on_simcard(numberToDial, _selectedSimCard);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Column(
          children: [
            RaisedButton(
                child: Text("Get All SimCards"),
                onPressed: () => getAllSimCard()),
            Container(
              padding: EdgeInsets.all(25),
              child: TextField(
                controller: Number_Call_Controler,
                keyboardType: TextInputType.text,
                cursorColor: Colors.green,
//                    autofocus: false,

                decoration: InputDecoration(
                  enabledBorder: OutlineInputBorder(
                    borderSide: BorderSide(color: Colors.transparent),
                    borderRadius: BorderRadius.all(Radius.circular(15)),
                  ),
                  focusedBorder: OutlineInputBorder(
                    borderSide: BorderSide(color: Colors.green),
                    borderRadius: BorderRadius.all(Radius.circular(15)),
                  ),
//                      labelText: "Fadlan Gali Lacagta",
                  hintText: "inputText",
                  filled: true,
                  fillColor: Colors.green.shade50,
                  hintStyle: TextStyle(color: Color(0XFF2c3e50)),
//                      labelStyle: TextStyle(
//                        fontFamily: 'OpenSans',
//                        color: Color(0XFF2c3e50),
//                      ),
                ),
              ),
            ),
            DropdownButton(
                value: _selectedSimCard,
                items: _simcards
                    .map((carrier) => DropdownMenuItem(
                          child: Text(carrier),
                          value: carrier,
                        ))
                    .toList(),
                onChanged: (e) => setState(() => _selectedSimCard = e)),
            RaisedButton(
                child: Text("Call On SimCard()"),
                onPressed: () => Call_On_SomCard()),
            Text('Abdifatah Muse Abdi')
          ],
        ),
      ),
    );
  }
}

==> sim_dhaman-0.0.4.tar.gz: example/lib/main.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:sim_dhaman/sim_dhaman.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  TextEditingController Number_Call_Controler = TextEditingController();
  String _selectedSimCard = "";
  List<String> _simcards = [];

  @override
  void initState() {
    super.initState();
    // initPlatformState();
  }

  getAllSimCard() async {
    var simcards = await SimDhaman.allsimcard();

    if (simcards.length > 0) {
      setState(() {
        _simcards = simcards;
        _selectedSimCard = simcards.first;
      });
    }

    print(simcards);
  }

  Call_On_SomCard() {
    var numberToDial = Number_Call_Controler.text;
    SimDhaman.callonsimcard(numberToDial, _selectedSimCard);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Column(
          children: [
            RaisedButton(
                child: Text("Get All SimCards"),
                onPressed: () => getAllSimCard()),
            Container(
              padding: EdgeInsets.all(25),
              child: TextField(
                controller: Number_Call_Controler,
                keyboardType: TextInputType.text,
                cursorColor: Colors.green,
//                    autofocus: false,

                decoration: InputDecoration(
                  enabledBorder: OutlineInputBorder(
                    borderSide: BorderSide(color: Colors.transparent),
                    borderRadius: BorderRadius.all(Radius.circular(15)),
                  ),
                  focusedBorder: OutlineInputBorder(
                    borderSide: BorderSide(color: Colors.green),
                    borderRadius: BorderRadius.all(Radius.circular(15)),
                  ),
//                      labelText: "Fadlan Gali Lacagta",
                  hintText: "inputText",
                  filled: true,
                  fillColor: Colors.green.shade50,
                  hintStyle: TextStyle(color: Color(0XFF2c3e50)),
//                      labelStyle: TextStyle(
//                        fontFamily: 'OpenSans',
//                        color: Color(0XFF2c3e50),
//                      ),
                ),
              ),
            ),
            DropdownButton(
                value: _selectedSimCard,
                items: _simcards
                    .map((carrier) => DropdownMenuItem(
                          child: Text(carrier),
                          value: carrier,
                        ))
                    .toList(),
                onChanged: (e) => setState(() => _selectedSimCard = e)),
            RaisedButton(
                child: Text("Call On SimCard()"),
                onPressed: () => Call_On_SomCard()),
            Text('Abdifatah Muse Abdi')
          ],
        ),
      ),
    );
  }
}
